Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Sender ¶
type Sender struct {
User string
Pass string
HTTPS bool
IP string
Port string
GameID string
HTTPClient *http.Client
Serial *serial.Serial
}
Sender will represent the connection between the scoreboard and the connector service
func (*Sender) CheckConnection ¶
CheckConnection will check if the scoreboard is reachable and return an error if not It is used by the ui to check after updating the Scoreboard config
func (*Sender) NextPlayer ¶
func (s *Sender) NextPlayer()
NextPlayer will send nextPlayer using sendToScoreboard
func (*Sender) Rematch ¶
func (s *Sender) Rematch()
Rematch will send rematch using sendToScoreboard
func (*Sender) UpdateStatus ¶
func (s *Sender) UpdateStatus()
UpdateStatus will fetch and update the status from the scoreboard with sendToScoreboard
Click to show internal directories.
Click to hide internal directories.